==> nmrium-0.50.1.tgz: package/lib/component/2d/1d-tracer/VerticalSliceChart.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useChartData } from '../../context/ChartContext';
import { PathBuilder } from '../../utility/PathBuilder';
import { getSliceYScale, useScale2DY } from '../utilities/scale';
function usePath(data, props) {
    const { reverse, width = 100, horizontalMargin = 10 } = props;
    const { mode } = useChartData();
    const scaleX = useScale2DY(reverse);
    const { x, re: y } = data;
    const scaleY = getSliceYScale(y, width, mode, { margin: horizontalMargin });
    const pathBuilder = new PathBuilder();
    pathBuilder.moveTo(scaleY(y.at(-1)), scaleX(x.at(-1)));
    for (let i = x.length - 2; i >= 0; i--) {
        pathBuilder.lineTo(scaleY(y[i]), scaleX(x[i]));
    }
    return pathBuilder.toString();
}
function VerticalSliceChart(props) {
    const { horizontalMargin = 10, data, reverse = false } = props;
    const { height, margin, displayerKey } = useChartData();
    const width = margin.left;
    const path = usePath(data, { width, horizontalMargin, reverse });
    const innerHeight = height - margin.bottom - margin.top;
    return (_jsxs("svg", { viewBox: `0 0 ${height} ${height}`, width: height, height: height, children: [_jsx("defs", { children: _jsx("clipPath", { id: `${displayerKey}clip-left`, children: _jsx("rect", { width: width, height: innerHeight, x: "0", y: margin.top }) }) }), _jsx("g", { clipPath: `url(#${displayerKey}clip-left)`, children: _jsx("path", { className: "line", stroke: "red", fill: "none", d: path }) })] }));
}
export default VerticalSliceChart;

==> nmrium-0.53.0.tgz: package/lib/component/2d/1d-tracer/VerticalSliceChart.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useChartData } from '../../context/ChartContext';
import useSpectrum from '../../hooks/useSpectrum';
import { PathBuilder } from '../../utility/PathBuilder';
import { getSliceYScale, useScale2DY } from '../utilities/scale';
function usePath(data, props) {
    const { reverse, width = 100, horizontalMargin = 10 } = props;
    const { mode } = useChartData();
    const scaleX = useScale2DY(reverse);
    const spectrum = useSpectrum();
    if (!data || !spectrum) {
        return '';
    }
    const { x, re: y } = data;
    const scaleY = getSliceYScale(spectrum.data, width, mode, {
        margin: horizontalMargin,
    });
    const pathBuilder = new PathBuilder();
    pathBuilder.moveTo(scaleY(y.at(-1)), scaleX(x.at(-1)));
    for (let i = x.length - 2; i >= 0; i--) {
        pathBuilder.lineTo(scaleY(y[i]), scaleX(x[i]));
    }
    return pathBuilder.toString();
}
function VerticalSliceChart(props) {
    const { horizontalMargin = 10, data, reverse = false } = props;
    const { height, margin, displayerKey } = useChartData();
    const width = margin.left;
    const path = usePath(data, { width, horizontalMargin, reverse });
    const innerHeight = height - margin.bottom - margin.top;
    return (_jsxs("svg", { viewBox: `0 0 ${height} ${height}`, width: height, height: height, children: [_jsx("defs", { children: _jsx("clipPath", { id: `${displayerKey}clip-left`, children: _jsx("rect", { width: width, height: innerHeight, x: "0", y: margin.top }) }) }), _jsx("g", { clipPath: `url(#${displayerKey}clip-left)`, children: _jsx("path", { className: "line", stroke: "red", fill: "none", d: path }) })] }));
}
export default VerticalSliceChart;
